<?php
/**
 * Custom comment Widget
 *
 * @package Theme Palace
 * @subpackage Daily Insight Pro
 * @since Daily Insight Pro 1.0
 */
if ( ! class_exists( 'Daily_Insight_Pro_Custom_Comment' ) ) :
/**
 * Custom comment Class
 *
 * @since 1.0
 *
 * @see WP_Widget
 */
class Daily_Insight_Pro_Custom_Comment extends WP_Widget {

	/**
	 * Sets up a new Custom Recent Comments widget instance.
	 *
	 * @since 1.0
	 * @access public
	 */
	public function __construct() {
		$widget_ops = array(
			'classname' => 'widget_recent_comments',
			'description' => esc_html__( 'Shows Your site&#8217;s most recent comments with extra features.','daily-insight-pro' ),
			'customize_selective_refresh' => true,
		);
		parent::__construct( 'tp-widget-recent-comments', esc_html__( 'TP: Custom Recent Comments', 'daily-insight-pro' ), $widget_ops );
		$this->alt_option_name = 'widget_recent_comments';
	}

	/**
	 * Outputs the content for the current Recent Comments widget instance.
	 *
	 * @since 1.0
	 * @access public
	 *
	 * @param array $args     Display arguments including 'before_title', 'after_title',
	 *                        'before_widget', and 'after_widget'.
	 * @param array $instance Settings for the current Recent Comments widget instance.
	 */
	public function widget( $args, $instance ) {
		if ( ! isset( $args['widget_id'] ) )
			$args['widget_id'] = $this->id;

		$output = '';

		$title = ( ! empty( $instance['title'] ) ) ? $instance['title'] : '';

		/** This filter is documented in wp-includes/widgets/class-wp-widget-pages.php */
		$title = apply_filters( 'widget_title', $title, $instance, $this->id_base );

		$post_type = !empty( $instance['post_type'] ) ? $instance['post_type'] : array( 'post' );

		$excerpt_length = !empty( $instance['excerpt_length'] ) ? $instance['excerpt_length'] : 10;

		$number = ! empty( $instance['number'] ) ? absint( $instance['number'] ) : 5;

		/**
		 * Filters the arguments for the Recent Comments widget.
		 *
		 * @since 1.0
		 *
		 * @see WP_Comment_Query::query() for information on accepted arguments.
		 *
		 * @param array $comment_args An array of arguments used to retrieve the recent comments.
		 */
		$comments = get_comments( apply_filters( 'widget_comments_args', array(
			'number'      => $number,
			'status'      => 'approve',
			'post_status' => 'publish',
			'post_type'   => $post_type,
		) ) );

		$output .= $args['before_widget'];
		if ( $title ) {
			$output .= 
			$args['before_title'] . esc_html( $title ) . $args['after_title'];
		}

		$output .= '<div class="widget-wrap"><ul>';
		if ( is_array( $comments ) && $comments ) {
			// Prime cache for associated posts. (Prime post term cache if we need it for permalinks.)
			$post_ids = array_unique( wp_list_pluck( $comments, 'comment_post_ID' ) );
			_prime_post_caches( $post_ids, strpos( get_option( 'permalink_structure' ), '%category%' ), false );

			foreach ( (array) $comments as $comment ) {	

				$comment_text =  $comment->comment_content;
				$source_content = preg_replace( '`\[[^\]]*\]`', '', $comment_text );
				$trimmed_content = wp_trim_words( $source_content, $excerpt_length, '...' );

				$output .= '<li class="recentcomments">';

				$output .= '<img src="'. get_template_directory_uri() .'/assets/uploads/comment-icon.png' .'" alt="'. esc_attr( get_the_title( $comment->comment_post_ID, false ) ) .'"><a href="'. esc_url( get_comments_link( $comment->comment_post_ID ) ) .'">'. esc_html( $trimmed_content ) .'</a>
							<time class="entry-date" datetime="'. esc_attr( $comment->comment_date_gmt ) .'">'.esc_html( get_comment_date( '', $comment->comment_ID ) ) .'</time>';
				$output .= '</li>';
			}
		}
		$output .= '</ul></div>';
		$output .= $args['after_widget'];

		echo $output;
	}

	/**
	 * Handles updating settings for the current Recent Comments widget instance.
	 *
	 * @since 1.0
	 * @access public
	 *
	 * @param array $new_instance New settings for this instance as input by the user via
	 *                            WP_Widget::form().
	 * @param array $old_instance Old settings for this instance.
	 * @return array Updated settings to save.
	 */
	public function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance['title'] = sanitize_text_field( $new_instance['title'] );
		$instance['number'] = absint( $new_instance['number'] );
		$instance['post_type'] =  $new_instance['post_type'];
		$instance['excerpt_length'] = absint( $new_instance['excerpt_length'] );
		return ( $instance ); 
	}

	/**
	 * Outputs the settings form for the Recent Comments widget.
	 *
	 * @since 1.0
	 * @access public
	 *
	 * @param array $instance Current settings.
	 */
	public function form( $instance ) {
		$defaults = array( 'title' =>  '', 'number' => 5 , 'post_type' => array( 'post' => 'post', 'page' => '' ), 'excerpt_length' => 10 );
		$instance = wp_parse_args ( $instance , $defaults );
		extract( $instance );
		?>
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php esc_html_e( 'Title:', 'daily-insight-pro' ); ?></label>
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>" />
		</p>

		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'number' ) ); ?>"><?php esc_html_e( 'Number of comments to show:', 'daily-insight-pro' ); ?></label>
			<input class="tiny-text" id="<?php echo esc_attr( $this->get_field_id( 'number' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'number' ) ); ?>" type="number" step="1" min="1" value="<?php echo absint( $number ); ?>" size="3" />
		</p>

		<span><?php esc_html_e( 'Show comments from:', 'daily-insight-pro' ); ?></span>

		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'post_type' ) ); ?>_post" style="display: block; float:left; width: 50%; margin-bottom: 5px"><?php esc_html_e( 'Post', 'daily-insight-pro' ); ?>
				<input class="checkbox" id="<?php echo esc_attr( $this->get_field_id( 'post_type' ) ); ?>_post" name="<?php echo esc_attr( $this->get_field_name( 'post_type' ) ); ?>[post]" type="checkbox" value="post" <?php if ( isset($post_type['post'] ) ) { checked( 'post', $post_type['post'], true ); } ?>/>
			</label>
		</p>

		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'post_type' ) ); ?>_page" style="display: block; float:left; width: 50%; margin-bottom: 5px"><?php esc_html_e( 'Page', 'daily-insight-pro' ); ?>
				<input class="checkbox" id="<?php echo esc_attr( $this->get_field_id( 'post_type' ) ); ?>_page" name="<?php echo esc_attr( $this->get_field_name( 'post_type' ) ); ?>[page]" type="checkbox" value="page" <?php if (isset($post_type['page'])) { checked( 'page', $post_type['page'], true ); } ?>/>
			</label>
		</p><br>

		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'excerpt_length' ) ); ?>" style="display: block; float:left; width: 100%; margin-bottom: 5px; clear: both; "><?php esc_html_e( 'Excerpt Length', 'daily-insight-pro' ); ?>
				<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'excerpt_length' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'excerpt_length' ) ); ?>" type="number" min="5" step="5" value="<?php echo absint( $excerpt_length ); ?>"/>
			</label>
		</p>
		<?php
	}
}
endif;
/*
 * Function to register custom recent comment widget
 *
 * Since 1.0
 */
function daily_insight_pro_register_custom_recent_comments(){
	register_widget( 'Daily_Insight_Pro_Custom_Comment' );
}
add_action( 'widgets_init', 'daily_insight_pro_register_custom_recent_comments' );